<?php

/**
 * Třída zavaděče aplikace
 *
 * @package    OTP
 * @author     Petr Jajtner <petr.jajtner@webbia.cz>
 * @copyright  Petr Jajtner © 2016
 */
class Bootstrap extends Zend_Application_Bootstrap_Bootstrap {

  /**
   * Nastaví automatické nahrávání souborů s třídami
   *
   * @return Zend_Application_Module_Autoloader
   */
  protected function _initAutoloader() {
    $resourceLoader = new Zend_Application_Module_Autoloader(array(
      'namespace' => '',
      'basePath'  => APPLICATION_PATH
    ));
    return $resourceLoader;
  }

  /**
   * Zavedení a nastavení view
   *
   * @return Zend_View
   */
  protected function _initViewSettings() {
    $this->bootstrap('view');
    $view = $this->getResource('view');
    $view->addScriptPath(APPLICATION_PATH.'/views/scripts/');
    $view->addHelperPath(APPLICATION_PATH.'/views/helpers/');

    $view->doctype('XHTML5');
    $view->application_title = 'Testovací aplikace OTP';

    Zend_Registry::set('Zend_View', $view);

    return $view;
  }

  /**
   * Zavedení databázového připojení
   *
   * @return Zend_Locale
   */
  protected function _initDatabase() {
    $this->bootstrap('db');
    $db = $this->getResource('db');

    Zend_Registry::set('Zend_Db', $db);

    return $db;
  }

  /**
   * Nastavení cache
   *
   * @return Zend_Cache
   */
  protected function _initCache() {
    $options = $this->getOption('cache');
    $cache = Zend_Cache::factory(
      $options['frontend'],
      $options['backend'],
      $options['frontendoptions'],
      $options['backendoptions']
    );

    Zend_Registry::set('Zend_Cache', $cache);
    Zend_Db_Table_Abstract::setDefaultMetadataCache($cache);

    return $cache;
  }

  /**
   * Zavedení lokálního nastavení
   *
   * @return Zend_Locale
   */
  protected function _initLocale() {
    $strLocale = 'cs_CZ';

    $locale = new Zend_Locale($strLocale);
    setlocale(LC_ALL, "{$strLocale}.utf8");
    mb_internal_encoding('utf-8');

    Zend_Registry::set('Zend_Locale', $locale);

    return $locale;
  }

  /**
   * Nastavení překladů
   *
   * @return Zend_Translate
   */
  protected function _initTranslation() {
    $locale = Zend_Registry::get('Zend_Locale');

    $arrayTranslator = new Zend_Translate(array(
      'adapter' => 'array',
      'content' => APPLICATION_PATH.'/resources/languages',
      'locale'  => $locale,
      'scan'    => Zend_Translate::LOCALE_DIRECTORY
    ));
    Zend_Validate_Abstract::setDefaultTranslator($arrayTranslator);

    $language = $locale->getLanguage();
    $csvTranslator = new Zend_Translate(array(
      'adapter'   => 'csv',
      'content'   => APPLICATION_PATH."/resources/{$language}.csv",
      'locale'    => $locale
    ));
    Zend_Registry::set('Zend_Translate', $csvTranslator);

    return $csvTranslator;
  }

}