<?php

/**
 * Kontroler pro přihlášení do systému
 *
 * @package    OTP
 * @author     Petr Jajtner <petr.jajtner@webbia.cz>
 * @copyright  Petr Jajtner © 2016
 */
class LoginController extends Zend_Controller_Action {

  const LOGIN_SESSION_EXPIRATION_TIME = 600; // 10 min.

  /**
   * Uložení informací o uživateli
   *
   * @var Zend_Session_Namespace
   */
  protected $_session = null;

  /**
   * Model pro uživatele
   *
   * @var Model_Users
   */
  protected $_modelUsers = null;

  /**
   * Inicializace kontroleru
   *
   * @return void
   */
  public function init() {
    $this->_session = new Zend_Session_Namespace(__CLASS__);
    $this->_modelUsers = new Model_Users();
  }

  /**
   * Výchozí akce
   */
  public function indexAction() {
    $selfUrl = $this->getHelper('Url')->simple('index');

    if (!isset($this->_session->id_user)) {
      $this->view->form = new Form_Login();
      $this->view->form->setAction($selfUrl);

      if ($this->_request->isPost() && $this->view->form->isValid($this->getAllParams())) {
        $values = $this->view->form->getValues();
        if (is_object($user = $this->_modelUsers->userExists($values['username'], $values['password']))) {
          $this->_session->id_user = $user->id_user;
          $this->_session->setExpirationSeconds(self::LOGIN_SESSION_EXPIRATION_TIME, 'id_user');
          $this->_redirect($this->getHelper('Url')->simple($selfUrl));
        }

        $message = array('error' => $this->view->translate('LNG_LOGIN_INDEX_FAILED'));
        $this->getHelper('FlashMessenger')->addMessage($message);

        $this->_redirect($this->getHelper('Url')->simple($selfUrl));
      }
    } else {
      $this->view->form = new Form_OTP();
      $this->view->form->setAction($selfUrl);

      if ($this->_request->isPost() && $this->view->form->isValid($this->getAllParams())) {
        $user = $this->_modelUsers->getUserById($this->_session->id_user);
        
        if (is_object($user) && $user->verifyOTP($this->view->form->getValue('otp'))) {
          unset($this->_session->id_user);
          Zend_Auth::getInstance()->getStorage()->write($user->allowAccess());
          $this->_redirect($this->getHelper('Url')->simple('index', 'index'));
        }

        $message = array('error' => $this->view->translate('LNG_LOGIN_INDEX_FAILED'));
        $this->getHelper('FlashMessenger')->addMessage($message);
        $this->_redirect($this->getHelper('Url')->simple('index', 'login'));
      }
    }

    $this->view->showLayout = false;
    $this->view->messages = $this->getHelper('FlashMessenger')->getMessages();
  }

}
