<?php

/**
 * Třída kontroleru pro správu účtů
 *
 * @package    OTP
 * @author     Petr Jajtner <petr.jajtner@webbia.cz>
 * @copyright  Petr Jajtner © 2016
 */
class UsersController extends Zend_Controller_Action {

  /**
   * Model pro účty
   *
   * @var Model_Users
   */
  protected $_modelUsers = null;

  /**
   * Aktuální stránka navigace
   *
   * @var Zend_Navigation_Page
   */
  protected $_current = null;

  /**
   * Inicializace kontroleru
   *
   * @return void
   */
  public function init() {
    if (!Zend_Auth::getInstance()->hasIdentity()) {
      $message = $this->view->translate('LNG_USERS_INDEX_BE_LOGGED');
      $this->getHelper('FlashMessenger')->addMessage(array('error' => $message));
      $this->_redirect($this->getHelper('Url')->simple('index', 'phone'));
    }

    $this->_modelUsers = new Model_Users();

    $this->_addCrumb(array(
      'label'      => 'LNG_COMMON_HOME',
      'controller' => 'admin',
      'action'     => 'index',
      'active'     => true
    ));
    $this->_addCrumb(array(
      'label'      => 'LNG_COMMON_USERS',
      'controller' => 'users',
      'action'     => 'index',
      'active'     => true
    ));
  }

  /**
   * Výchozí akce
   */
  public function indexAction() {
    $this->view->users = $this->_modelUsers->fetchAll();
    $this->view->messages = $this->getHelper('FlashMessenger')->getMessages();
  }

  /**
   * Akce pro úpravu účtu
   */
  public function editAction() {
    $this->view->form = new Form_User();
    $this->view->form->setAction($this->getHelper('Url')->simple('edit'));

    $this->view->form->removeElement('user_name');
    $this->view->form->removeElement('user_password');
    $this->view->form->removeElement('user_password2');
    $this->view->form->removeElement('url');

    $user = null;
    if ($this->_request->isPost() && $this->view->form->isValid($this->getAllParams())) {
      $id_user = $this->view->form->getValue('id_user');
      if (!is_object($user = $this->_modelUsers->getUserById($id_user))) {
        $user = $this->_modelUsers->createRow();
      }
      if ($user->setFromArray($this->view->form->getValues())->save()) {
        $this->_redirect($this->getHelper('Url')->simple('index'));
      }
    }

    if (is_numeric($id_user = $this->_getParam('id')) &&
        is_object($user = $this->_modelUsers->getUserById($id_user))) {
      $this->view->form->populate($user->toArray());
    }

    $title = $this->view->form->getValue('id_user')
           ? 'LNG_USERS_INDEX_EDIT'
           : 'LNG_USERS_INDEX_NEW';
    $this->view->title = $this->view->translate($title);

    $this->_addCrumb(array(
      'label'      => $title,
      'controller' => 'users',
      'action'     => 'edit',
      'active'     => true
    ));
  }

  /**
   * Akce pro smazání účtu
   */
  public function deleteAction() {
    if (is_numeric($id_user = $this->_getParam('id')) &&
        is_object($user = $this->_modelUsers->getUserById($id_user))) {
      $user->delete();
    }
    $this->_redirect($this->getHelper('Url')->simple('index'));
  }

  /**
   * Přidá drobek do navigace
   *
   * @param array|Zend_Config $options
   * @return void
   */
  protected function _addCrumb($options) {
    $page = Zend_Navigation_Page::factory($options);

    if (is_null($this->_current)) {
      $this->view->breadcrumbs = new Zend_Navigation();
      $this->view->breadcrumbs->addPage($page);
      $this->_current = $this->view->breadcrumbs->current();
    } else {
      $this->_current->addPage($page);
      $this->_current = $this->_current->current();
    }
  }

}