<?php

/**
 * Třída formuláře pro přihlášení uživatele
 *
 * @package    OTP
 * @author     Petr Jajtner <petr.jajtner@webbia.cz>
 * @copyright  Petr Jajtner © 2016
 */
class Form_Login extends Zend_Form {

  /**
   * Nastavení dekorátoru formuláře
   *
   * @var array
   */
  protected $_formDecorator = array(
    array('ViewScript', array('viewScript' => 'forms/login.phtml')),
    'Form'
  );

  /**
   * Inicializace formuláře
   *
   * @return void
   */
  public function init() {
    $this->setMethod('post');
    $this->setAttrib('id', 'login-form');

    // -- data --
    $username = $this->createElement('text', 'username');
    $username->setLabel('LNG_USER_FORM_USER_NAME');
    $username->setRequired(true);
    $username->setAttrib('placeholder', $this->getView()->translate('LNG_LOGIN_FORM_USERNAME_PLACEHOLDER'));
    $username->setFilters(array('StripTags', 'StringTrim'));
    $username->setValidators(array(
      'NotEmpty',
      array('StringLength', true, array(3, 128))
    ));
    $this->addElement($username);

    $password = $this->createElement('password', 'password');
    $password->setRequired(true);
    $password->setAttrib('placeholder', $this->getView()->translate('LNG_LOGIN_FORM_PASSWORD_PLACEHOLDER'));
    $password->setFilters(array('StripTags', 'StringTrim'));
    $username->setValidators(array(
      'NotEmpty',
      array('StringLength', true, array(3, 128))
    ));
    $this->addElement($password);

    // -- tlačítka --
    $submit = $this->createElement('submit', 'submit');
    $submit->setLabel('LNG_LOGIN_FORM_SUBMIT');
    $submit->setDecorators(array('ViewHelper'));
    $this->addElement($submit);
  }

  /**
   * Načte výchozí dekorátory a nastaví nové vlastnosti
   *
   * @return Form_Login
   */
  public function loadDefaultDecorators() {
    parent::loadDefaultDecorators();

    return $this->setDecorators($this->_formDecorator);
  }

}
