<?php

/**
 * Třída formuláře pro editaci účtu
 *
 * @package    OTP
 * @author     Petr Jajtner <petr.jajtner@webbia.cz>
 * @copyright  Petr Jajtner © 2016
 */
class Form_User extends Zend_Form {

  /**
   * Nastavení dekorátoru formuláře
   *
   * @var array
   */
  protected $_formDecorator = array(
    array('ViewScript', array('viewScript' => 'forms/user.phtml')),
    'Form'
  );

  /**
   * Inicializace formuláře
   *
   * @return void
   */
  public function init() {
    $this->setMethod('post');
    $this->setAttrib('id', 'user-form');
    $this->addElementPrefixPath('Custom_Validate_', 'Custom/Validate/', 'Validate');

    // - data -
    $firstName = $this->createElement('text', 'first_name');
    $firstName->setLabel('LNG_USER_FORM_FIRST_NAME');
    $firstName->setRequired(true);
    $firstName->setFilters(array('StripTags', 'StringTrim'));
    $firstName->setValidators(array(
      'NotEmpty',
      array('StringLength', true, array(2, 128))
    ));
    $this->addElement($firstName);

    $lastName = $this->createElement('text', 'last_name');
    $lastName->setLabel('LNG_USER_FORM_LAST_NAME');
    $lastName->setRequired(true);
    $lastName->setFilters(array('StripTags', 'StringTrim'));
    $lastName->setValidators(array(
      'NotEmpty',
      array('StringLength', true, array(3, 128))
    ));
    $this->addElement($lastName);

    $email = $this->createElement('text', 'email');
    $email->setLabel('LNG_USER_FORM_EMAIL');
    $email->setRequired(true);
    $email->setFilters(array('StripTags', 'StringTrim'));
    $email->setValidators(array(
      array('StringLength', true, array(6, 255)),
      array('EmailAddress', true),
      'UniqueEmail'
    ));
    $this->addElement($email);

    $userName = $this->createElement('text', 'user_name');
    $userName->setLabel('LNG_USER_FORM_USER_NAME');
    $userName->setRequired(true);
    $userName->setFilters(array('StripTags', 'StringTrim'));
    $userName->setValidators(array(
      'NotEmpty',
      array('StringLength', true, array(3, 128))
    ));
    $this->addElement($userName);

    $userPassword1 = $this->createElement('password', 'user_password');
    $userPassword1->setLabel('LNG_USER_FORM_USER_PASSWORD');
    $userPassword1->setRequired(true);
    $userPassword1->setFilters(array('StripTags', 'StringTrim'));
    $userPassword1->setValidators(array(
      array('StringLength', true, array('min' => 6))
    ));
    $this->addElement($userPassword1);

    $userPassword2 = $this->createElement('password', 'user_password2');
    $userPassword2->setLabel('LNG_USER_FORM_VERIFY_PASSWORD');
    $userPassword2->setRequired(true);
    $userPassword2->setFilters(array('StripTags', 'StringTrim'));
    $userPassword2->setValidators(array(
      array('StringLength', true, array('min' => 6)),
      array('Identical', true, array('token' => 'user_password'))
    ));
    $this->addElement($userPassword2);

    $otpType = $this->createElement('radio', 'otp_type');
    $otpType->setLabel('LNG_USER_FORM_OTP_TYPE');
    $otpType->setRequired(true);
    $otpType->setMultiOptions(Model_Users::$OTP_TYPES);
    $otpType->setSeparator('');
    $otpType->setValidators(array(
      array('InArray', true, array('haystack' => array_keys(Model_Users::$OTP_TYPES))),
    ));
    $otpType->setDecorators(array(
      array('ViewScript', array('viewScript' => 'forms/radio.phtml')),
      array('Errors')
    ));
    $this->addElement($otpType);

    $url = $this->createElement('text', 'url');
    $url->setLabel('LNG_USER_FORM_NOSPAM');
    $url->setRequired(true);
    $url->addFilters(array('StripTags', 'StringTrim', 'StringToLower'));
    $url->addValidators(array(
      array('Identical', true, array('token' => 'nospam'))
    ));
    $this->addElement($url);

    // - tlačítka -
    $submit = $this->createElement('submit', 'submit');
    $submit->setLabel('LNG_COMMON_FORM_SAVE');
    $submit->setDecorators(array('ViewHelper'));
    $this->addElement($submit);

    $cancel = $this->createElement('button', 'cancel');
    $cancel->setLabel('LNG_COMMON_FORM_CANCEL');
    $cancel->setDecorators(array('ViewHelper'));
    $this->addElement($cancel);

    // - skryté -
    $idUser = $this->createElement('hidden', 'id_user');
    $idUser->setDecorators(array('ViewHelper'));
    $this->addElement($idUser);

    $this->addDisplayGroup(array('id_user', 'submit', 'cancel'), 'submits');
  }

  /**
   * Načte výchozí dekorátory a nastaví nové vlastnosti
   *
   * @return Form_User
   */
  public function loadDefaultDecorators() {
    parent::loadDefaultDecorators();

    $group = $this->getDisplayGroup('submits');
    $group->removeDecorator('Fieldset');
    $group->removeDecorator('HtmlTag');
    $group->getDecorator('DtDdWrapper')->setOption('dtLabel', '');

    return $this->setDecorators($this->_formDecorator);
  }

}
