<?php

/**
 * Třída validátoru pro jedinečný email v systému
 *
 * @package    OTP
 * @author     Petr Jajtner <petr.jajtner@webbia.cz>
 * @copyright  Petr Jajtner © 2016
 */
class Custom_Validate_UniqueEmail extends Zend_Validate_Abstract {

  const EMAIL_EXISTS = 'emailExists';

  /**
   * Chybové zprávy
   *
   * @var array
   */
  protected $_messageTemplates = array(
    self::EMAIL_EXISTS => 'Email „%value%” již v systému existuje',
  );

  /**
   * Kontrola jedinečného emailu
   *
   * @param string $value
   * @param mixed $context
   * @return boolean
   */
  public function isValid($value, $context = null) {
    $value = (string) $value;
    $this->_setValue($value);

    $isValid = true;
    $modelUsers = new Model_Users();
    
    if (!is_object($user = $modelUsers->getUserByEmail($value))) {
      return $isValid;
    }

    if (isset($context['id_user'])) { // Pokud máme kontext o uživateli
      $isValid = $user->id_user === $context['id_user'];
    } else { // jinak předpokládáme, že uživatel již existuje
      $isValid = false;
    }

    if (!$isValid) {
      $this->_error(self::EMAIL_EXISTS);
    }

    return $isValid;
  }

}
