<?php

/**
 * Třída pro práci s tabulkou users
 *
 * @package    OTP
 * @author     Petr Jajtner <petr.jajtner@webbia.cz>
 * @copyright  Petr Jajtner © 2016
 */
class Model_Users extends Zend_Db_Table_Abstract {

  const OTP_TYPE_HOTP = 'hotp';
  const OTP_TYPE_TOTP = 'totp';

  /**
   * Druhy OTP
   *
   * @var array
   */
  public static $OTP_TYPES = array(
    self::OTP_TYPE_HOTP => 'LNG_USER_FORM_OTP_HOTP',
    self::OTP_TYPE_TOTP => 'LNG_USER_FORM_OTP_TOTP'
  );

  /**
   * Název tabulky
   *
   * @var string
   */
  protected $_name = 'users';

  /**
   * Sloupec primárního klíče
   *
   * @var string
   */
  protected $_primary = 'id_user';

  /**
   * Třída řádku
   *
   * @var string
   */
  protected $_rowClass = 'Model_User';

  /**
   * Vrátí uživatele dle $id_user
   *
   * @param integer $id_user
   * @return Model_User
   */
  public function getUserById($id_user) {
    return $this->find($id_user)->current();
  }

  /**
   * Vrátí uživatele dle $email (email musí být v systému unikátní)
   *
   * @param string $email
   * @return Model_User
   */
  public function getUserByEmail($email) {
    return $this->fetchRow(array('email = ?' => $email));
  }

  /**
   * Vrátí uživatele dle platného OTP
   *
   * @todo Dodělat podle specifikace
   *
   * @param string $otp
   * @return Model_User
   */
  public function getUserByValidOTP($otp) {
    $select = $this->select()
                   ->where('otp = SHA(?)', $otp)
                   ->where('valid_to > NOW()');
    return $this->fetchRow($select);
  }

  /**
   * Otestuje, zdali existuje uživatel s danými přihlašovacími údaji
   *
   * @param string $user_name
   * @param string $user_password
   * @param array $where
   * @return Model_User
   */
  public function userExists($user_name, $user_password, array $where = array()) {
    $where['user_name = ?'] = $user_name;
    $users = $this->fetchAll($where);
    foreach ($users as $user) {
      if (password_verify($user_password, $user->user_password)) {
        return $user->setValid();
      }
    }
    return null;
  }

}
